@@ -25,7 +25,7 @@ PyObject *DateTimeFromString(char *str)
 const size_t trim(const char *str, size_t len)
 {
     len--;
-    while (*(str + len) == ' ')
+    while ((*(str + len) == ' ') || *(str + len) == (char)0)
     {
         len--;
     }
