@@ -26,6 +26,10 @@ static PyObject *m = NULL;
 PyMODINIT_FUNC PyInit_rsrfile(void)
 {
     m = PyModule_Create(&rsrfile);
+    if (m == NULL)
+    {
+        return NULL;
+    }
 
     PyDateTime_IMPORT;
 
@@ -33,6 +37,7 @@ PyMODINIT_FUNC PyInit_rsrfile(void)
     PyStructSequence_InitType(&MCSSummaryType, &MCSSummaryType_desc);
     PyStructSequence_InitType(&UNCSummaryType, &UNCSummaryType_desc);
     PyStructSequence_InitType(&TdepSummaryType, &TdepSummaryType_desc);
+    PyStructSequence_InitType(&ResSummaryMiscType, &ResSummaryMiscType_desc);
 
     PyStructSequence_InitType(&MCSEventType, &MCSEventType_desc);
 
